@@ -4,13 +4,15 @@ from pm4py.algo.conformance.tokenreplay import algorithm as token_replay
 from pm4py.algo.discovery.inductive import algorithm as inductive_miner
 from pm4py.objects.log.importer.xes import importer as xes_importer
 from pm4py.visualization.petri_net import visualizer as pn_vis
+from pm4py.objects.conversion.process_tree import converter as process_tree_converter
 
 
 def execute_script():
     log_path = os.path.join("..", "tests", "input_data", "running-example.xes")
     log = xes_importer.apply(log_path)
     print("loaded log")
-    net, marking, final_marking = inductive_miner.apply(log)
+    process_tree = inductive_miner.apply(log)
+    net, marking, final_marking = process_tree_converter.apply(process_tree)
     for place in marking:
         print("initial marking " + place.name)
     for place in final_marking:
