@@ -17,7 +17,7 @@
 import pkgutil
 from enum import Enum
 
-from pm4py.objects.log.importer.xes.variants import iterparse, line_by_line, iterparse_mem_compressed, iterparse_20
+from pm4py.objects.log.importer.xes.variants import iterparse, line_by_line, iterparse_mem_compressed, iterparse_20, chunk_regex
 
 
 class Variants(Enum):
@@ -25,12 +25,13 @@ class Variants(Enum):
     LINE_BY_LINE = line_by_line
     ITERPARSE_MEM_COMPRESSED = iterparse_mem_compressed
     ITERPARSE_20 = iterparse_20
+    CHUNK_REGEX = chunk_regex
 
 
 if pkgutil.find_loader("lxml"):
     DEFAULT_VARIANT = Variants.ITERPARSE
 else:
-    DEFAULT_VARIANT = Variants.LINE_BY_LINE
+    DEFAULT_VARIANT = Variants.CHUNK_REGEX
 
 
 def apply(path, parameters=None, variant=DEFAULT_VARIANT):
@@ -62,8 +63,15 @@ def apply(path, parameters=None, variant=DEFAULT_VARIANT):
         variant = Variants.LINE_BY_LINE
     elif variant == 'iterparse':
         variant = Variants.ITERPARSE
+    elif variant == 'chunk_regex':
+        variant = Variants.CHUNK_REGEX
 
-    return variant.value.apply(path, parameters=parameters)
+    log = variant.value.apply(path, parameters=parameters)
+
+    return log
+
+    #from pm4py.objects.conversion.log import converter as log_converter
+    #return log_converter.apply(log, variant=log_converter.Variants.TO_DATA_FRAME, parameters=parameters)
 
 
 def deserialize(log_string, parameters=None, variant=DEFAULT_VARIANT):
