@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.petri.reachability_graph import construct_reachability_graph
+from pm4py.objects.petri_net.utils.reachability_graph import construct_reachability_graph
 from pm4py.objects.conversion.log import converter as log_converter
 
 
@@ -45,8 +45,8 @@ def get_tangible_reachability_from_log_net_im_fm(log, net, im, fm, parameters=No
     if parameters is None:
         parameters = {}
 
-    from pm4py.simulation.montecarlo.utils import replay
-    stochastic_info = replay.get_map_from_log_and_net(log_converter.apply(log, parameters=parameters), net, im, fm,
+    from pm4py.algo.simulation.montecarlo.utils import replay
+    stochastic_info = replay.get_map_from_log_and_net(log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters), net, im, fm,
                                                       parameters=parameters)
 
     reachability_graph, tangible_reachability_graph = get_tangible_reachability_from_net_im_sinfo(net, im,
@@ -80,7 +80,7 @@ def get_tangible_reachability_from_net_im_sinfo(net, im, stochastic_info, parame
     """
     if parameters is None:
         parameters = {}
-    reachab_graph = construct_reachability_graph(net, im)
+    reachab_graph = construct_reachability_graph(net, im, use_trans_name=True)
     tang_reach_graph = get_tangible_reachability_from_reachability(reachab_graph, stochastic_info)
 
     return reachab_graph, tang_reach_graph
