@@ -53,7 +53,7 @@ def apply(trie: Trie, variant=Variants.CLASSIC, parameters: Optional[Dict[Any, A
     return exec_utils.get_variant(variant).apply(trie, parameters=parameters)
 
 
-def save(gviz: Graph, output_file_path: str):
+def save(gviz: Graph, output_file_path: str, parameters=None):
     """
     Save the diagram
 
@@ -64,10 +64,10 @@ def save(gviz: Graph, output_file_path: str):
     output_file_path
         Path where the GraphViz output should be saved
     """
-    gsave.save(gviz, output_file_path)
+    gsave.save(gviz, output_file_path, parameters=parameters)
 
 
-def view(gviz: Graph):
+def view(gviz: Graph, parameters=None):
     """
     View the diagram
 
@@ -76,10 +76,10 @@ def view(gviz: Graph):
     gviz
         GraphViz diagram
     """
-    return gview.view(gviz)
+    return gview.view(gviz, parameters=parameters)
 
 
-def matplotlib_view(gviz: Graph):
+def matplotlib_view(gviz: Graph, parameters=None):
     """
     Views the diagram using Matplotlib
 
@@ -89,4 +89,4 @@ def matplotlib_view(gviz: Graph):
         Graphviz
     """
 
-    return gview.matplotlib_view(gviz)
+    return gview.matplotlib_view(gviz, parameters=parameters)
